diff genshi/template/markup.py @ 809:92c5d936616b

Revert [914] for now, see #293.
author cmlenz
date Fri, 06 Mar 2009 11:55:07 +0000
parents 1b6968d31089
children 3047d5d83ccc
line wrap: on
line diff
--- a/genshi/template/markup.py
+++ b/genshi/template/markup.py
@@ -329,9 +329,10 @@
 
         for event in stream:
 
             # We (currently) only care about start events for matching
             # We might care about namespace events in the future, though
-            if not match_templates or event[0] is not START:
+            if not match_templates or (event[0] is not START and
+                                       event[0] is not END):
                 yield event
                 continue
 
@@ -329,9 +329,10 @@
         for event in stream:
 
-            # We (currently) only care about start events for matching
+            # We (currently) only care about start and end events for matching
             # We might care about namespace events in the future, though
Copyright (C) 2012-2017 Edgewall Software